@@ -36,11 +36,22 @@
 
 #include <gconf/gconf-client.h>
 #include <glade/glade-xml.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtklinkbutton.h>
+#include <gtk/gtk.h>
 #include <libgnomeui/gnome-druid.h>
 #include <libgnomeui/gnome-druid-page-standard.h>
 
+#include "exchange-storage.h"
+
+#ifdef G_OS_WIN32
+
+#undef CONNECTOR_GLADEDIR
+#define CONNECTOR_GLADEDIR _exchange_storage_gladedir
+
+#undef CONNECTOR_IMAGESDIR
+#define CONNECTOR_IMAGESDIR _exchange_storage_imagesdir
+
+#endif
+
 typedef struct {
 	GnomeDruid *druid;
 
@@ -82,9 +93,8 @@ static void owa_page_changed (GtkEntry *entry, ExchangeAutoconfigGUI *gui);
 static void gc_page_changed (GtkEntry *entry, ExchangeAutoconfigGUI *gui);
 static void verify_page_changed (GtkEntry *entry, ExchangeAutoconfigGUI *gui);
 
-
 static void
-autoconfig_gui_set_page (ExchangeAutoconfigGUI *gui, int page)
+autoconfig_gui_set_page (ExchangeAutoconfigGUI *gui, gint page)
 {
 	gnome_druid_set_page (gui->druid, gui->pages->pdata[page]);
 }
@@ -98,7 +108,6 @@ autoconfig_gui_set_next_sensitive (ExchangeAutoconfigGUI *gui,
 					   TRUE, FALSE);
 }
 
-
 #define SETUP_ENTRY(name, changed)				\
 	gui->name = (GtkEntry *)				\
 		glade_xml_get_widget (gui->xml, #name);		\
@@ -109,10 +118,15 @@ static ExchangeAutoconfigGUI *
 autoconfig_gui_new (void)
 {
 	ExchangeAutoconfigGUI *gui;
+	gchar *gladefile;
 
 	gui = g_new0 (ExchangeAutoconfigGUI, 1);
 
-	gui->xml = glade_xml_new (CONNECTOR_GLADEDIR "/exchange-autoconfig-wizard.glade", NULL, NULL);
+	gladefile = g_build_filename (CONNECTOR_GLADEDIR,
+				      "exchange-autoconfig-wizard.glade",
+				      NULL);
+	gui->xml = glade_xml_new (gladefile, NULL, NULL);
+	g_free (gladefile);
 	if (!gui->xml) {
 		g_warning ("Could not find exchange-autoconfig-wizard.glade");
 		g_free (gui);
@@ -143,14 +157,12 @@ autoconfig_gui_new (void)
 	return gui;
 }
 
-
 static inline gboolean
 check_field (GtkEntry *entry)
 {
 	return (*gtk_entry_get_text (entry) != '\0');
 }
 
-
 static void
 owa_page_prepare (ExchangeAutoconfigGUI *gui)
 {
@@ -170,7 +182,7 @@ static gboolean
 owa_page_next (ExchangeAutoconfigGUI *gui)
 {
 	E2kAutoconfigResult result;
-	const char *old, *new;
+	const gchar *old, *new;
 
 	e2k_autoconfig_set_owa_uri (gui->ac, gtk_entry_get_text (gui->owa_uri_entry));
 	e2k_autoconfig_set_username (gui->ac, gtk_entry_get_text (gui->username_entry));
@@ -251,12 +263,13 @@ owa_page_next (ExchangeAutoconfigGUI *gui)
 	case E2K_AUTOCONFIG_CANT_BPROPFIND:
 		gtk_label_set_text (
 			gui->failure_label,
-			_("Ximian Connector requires access to certain "
-			  "functionality on the Exchange Server that appears "
-			  "to be disabled or blocked.  (This is usually "
-			  "unintentional.)  Your Exchange Administrator will "
-			  "need to enable this functionality in order for "
-			  "you to be able to use Ximian Connector.\n\n"
+			_("Evolution Connector for Microsoft Exchange requires "
+			  "access to certain functionality on the Exchange "
+			  "server that appears to be disabled or blocked.  "
+			  "(This is usually unintentional.)  Your Exchange "
+			  "administrator will need to enable this "
+			  "functionality in order for you to be able to use "
+			  "the Evolution Connector.\n\n"
 			  "For information to provide to your Exchange "
 			  "administrator, please follow the link below:"));
 
@@ -273,8 +286,9 @@ owa_page_next (ExchangeAutoconfigGUI *gui)
 		gtk_label_set_text (
 			gui->failure_label,
 			_("The Exchange server URL you provided is for an "
-			  "Exchange 5.5 Server. Ximian Connector supports "
-			  "Microsoft Exchange 2000 and 2003 only."));
+			  "Exchange 5.5 server. Evolution Connector for "
+			  "Microsoft Exchange supports Microsoft Exchange 2000 "
+			  "and 2003 only."));
 
 		if (gui->failure_href) {
 			gtk_widget_destroy (gui->failure_href);
@@ -317,7 +331,7 @@ gc_page_next (ExchangeAutoconfigGUI *gui)
 {
 	E2kAutoconfigResult result;
 
-	e2k_autoconfig_set_gc_server (gui->ac, gtk_entry_get_text (gui->gc_server_entry), -1);
+	e2k_autoconfig_set_gc_server (gui->ac, gtk_entry_get_text (gui->gc_server_entry), -1, E2K_AUTOCONFIG_USE_GAL_DEFAULT);
 
 	gtk_widget_set_sensitive (GTK_WIDGET (gui->window), FALSE);
 	e2k_operation_init (&gui->op);
@@ -403,7 +417,7 @@ verify_page_next (ExchangeAutoconfigGUI *gui)
 static gboolean
 verify_page_check (ExchangeAutoconfigGUI *gui)
 {
-	const char *email;
+	const gchar *email;
 
 	email = gtk_entry_get_text (gui->email_entry);
 
@@ -433,7 +447,7 @@ autoconfig_gui_apply (ExchangeAutoconfigGUI *gui)
 	EAccount *account;
 	EIterator *iter;
 	GConfClient *gconf;
-	char *pw_key;
+	gchar *pw_key;
 	gboolean found = FALSE;
 
 	/* Create the account. */
@@ -509,7 +523,7 @@ autoconfig_gui_free (ExchangeAutoconfigGUI *gui)
 }
 
 static struct {
-	const char *page_name, *body_name;
+	const gchar *page_name, *body_name;
 	void (*prepare_func) (ExchangeAutoconfigGUI *gui);
 	gboolean (*back_func) (ExchangeAutoconfigGUI *gui);
 	gboolean (*next_func) (ExchangeAutoconfigGUI *gui);
@@ -523,14 +537,14 @@ static struct {
 	{ "verify_page", "verify_page_vbox", verify_page_prepare,
 	  verify_page_back, verify_page_next }
 };
-static const int num_autoconfig_pages = sizeof (autoconfig_pages) / sizeof (autoconfig_pages[0]);
+static const gint num_autoconfig_pages = sizeof (autoconfig_pages) / sizeof (autoconfig_pages[0]);
 
 /* Autoconfig druid */
 
-static int
+static gint
 find_page (ExchangeAutoconfigGUI *gui, gpointer page)
 {
-	int page_num;
+	gint page_num;
 
 	for (page_num = 0; page_num < gui->pages->len; page_num++) {
 		if (gui->pages->pdata[page_num] == (gpointer)page)
@@ -544,7 +558,7 @@ static gboolean
 druid_next_cb (GnomeDruidPage *page, GtkWidget *druid,
 	       ExchangeAutoconfigGUI *gui)
 {
-	int page_num = find_page (gui, page);
+	gint page_num = find_page (gui, page);
 
 	if (page_num == -1 || !autoconfig_pages[page_num].next_func)
 		return FALSE;
@@ -556,7 +570,7 @@ static void
 druid_prepare_cb (GnomeDruidPage *page, GtkWidget *druid,
 		  ExchangeAutoconfigGUI *gui)
 {
-	int page_num = find_page (gui, page);
+	gint page_num = find_page (gui, page);
 
 	if (page_num == -1 || !autoconfig_pages[page_num].prepare_func)
 		return;
@@ -568,7 +582,7 @@ static gboolean
 druid_back_cb (GnomeDruidPage *page, GtkWidget *druid,
 	       ExchangeAutoconfigGUI *gui)
 {
-	int page_num = find_page (gui, page);
+	gint page_num = find_page (gui, page);
 
 	if (page_num == -1 || !autoconfig_pages[page_num].back_func)
 		return FALSE;
@@ -602,7 +616,8 @@ exchange_autoconfig_druid_run (void)
 	ExchangeAutoconfigGUI *gui;
 	GtkWidget *page;
 	GdkPixbuf *icon;
-	int i;
+	gint i;
+	gchar *pngfile;
 
 	gui = autoconfig_gui_new ();
 	g_return_if_fail (gui);
@@ -612,7 +627,11 @@ exchange_autoconfig_druid_run (void)
 	gui->window = (GtkWindow *)glade_xml_get_widget (gui->xml, "window");
 	gui->pages = g_ptr_array_new ();
 
-	icon = gdk_pixbuf_new_from_file (CONNECTOR_IMAGESDIR "/connector.png", NULL);
+	pngfile = g_build_filename (CONNECTOR_IMAGESDIR,
+				    "connector.png",
+				    NULL);
+	icon = gdk_pixbuf_new_from_file (pngfile, NULL);
+	g_free (pngfile);
 	for (i = 0; i < num_autoconfig_pages; i++) {
 		page = glade_xml_get_widget (gui->xml, autoconfig_pages[i].page_name);
 		g_ptr_array_add (gui->pages, page);
