@@ -6,14 +6,11 @@
 
 #include <exchange-types.h>
 #include <exchange-constants.h>
-#include <e-util/e-account-list.h>
+#include <libedataserver/e-account-list.h>
 #include <libedataserver/e-source-list.h>
 #include <libedataserver/e-source-group.h>
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define EXCHANGE_TYPE_CONFIG_LISTENER            (exchange_config_listener_get_type ())
 #define EXCHANGE_CONFIG_LISTENER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EXCHANGE_TYPE_CONFIG_LISTENER, ExchangeConfigListener))
@@ -55,11 +52,10 @@ ExchangeConfigListener *exchange_config_listener_new      (void);
 
 GSList                 *exchange_config_listener_get_accounts (ExchangeConfigListener *config_listener);
 
-void 			add_folder_esource (ExchangeAccount *account, FolderType folder_type, const char *folder_name, const char *physical_uri);
-void 			remove_folder_esource (ExchangeAccount *account, FolderType folder_type, const char *physical_uri);
+void			exchange_config_listener_migrate_esources (ExchangeConfigListener *config_listener);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+void			add_folder_esource (ExchangeAccount *account, FolderType folder_type, const gchar *folder_name, const gchar *physical_uri);
+void			remove_folder_esource (ExchangeAccount *account, FolderType folder_type, const gchar *physical_uri);
+G_END_DECLS
 
 #endif /* __EXCHANGE_CONFIG_LISTENER_H__ */
